@@ -1,10 +1,9 @@
 /*
-  $Id: MbtServer.cxx 16819 2014-01-06 10:08:54Z sloot $
-  $URL: https://ilk.uvt.nl/svn/trunk/sources/MbtServer/src/MbtServer.cxx $
-  Copyright (c) 1998 - 2014
+  Copyright (c) 1998 - 2016
+  CLST  - Radboud University
   ILK   - Tilburg University
   CLiPS - University of Antwerp
- 
+
   This file is part of mbtserver
 
   mbtserver is free software; you can redistribute it and/or modify
@@ -21,17 +20,20 @@
   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
-      http://ilk.uvt.nl/software.html
+      https://github.com/LanguageMachines/mbt/issues
   or send mail to:
-      timbl@uvt.nl
+      lamasoftware (at ) science.ru.nl
+
 */
 
 #include <string>
+#include <iostream>
 #include "mbtserver/MbtServerBase.h"
 
-int main(int argc, char *argv[]) {
-  TimblOpts opts( argc, argv );
-  MbtServer::StartServer( opts );   
+int main( int argc, const char *argv[]) {
+  TiCC::CL_Options opts( Tagger::mbt_short_opts + "S:",
+			 Tagger::mbt_long_opts + ",config:,logfile:,pidfile:,daemonize:" );
+  opts.init( argc, argv );
+  MbtServer::StartServer( opts );
   exit(EXIT_SUCCESS);
 }
-
